@@ -1,8 +1,7 @@
-import os
-from typing import Dict, BinaryIO
+from typing import BinaryIO
 
 from eyesonly.acl.acl_type import ACLType
-from eyesonly.acl.providers.base_file_acl_provider import BaseACLProvider
+from eyesonly.acl.providers.base_file_acl_provider import BaseFileACLProvider
 
 try:
     import tomllib
@@ -10,7 +9,7 @@ except ModuleNotFoundError:
     import tomli as tomllib
 
 
-class TomlACLProvider(BaseACLProvider):
+class TomlACLProvider(BaseFileACLProvider):
     def __init__(self, file_path: str = 'eyesonly.toml'):
         super().__init__(file_path=file_path)
 
